@@ -30,11 +30,11 @@ import mimetypes
 import rfc822
 import time
 import string
+import sys
 from os import path, stat
-
-
 from wsgiref import util
-
+from wsgiref.simple_server import make_server
+from optparse import OptionParser
 
 try: from pkg_resources import resource_filename, Requirement
 except: pass
@@ -360,15 +360,51 @@ class KidMagic(StringMagic):
         return [template.serialize()]
 
 
-if __name__ == '__main__':
+def command():
+    parser = OptionParser(usage="%prog DIR [HOST][:][PORT]", 
+                          version="static 0.3.6")
+    options, args = parser.parse_args()
+    if len(args) in (1, 2):
+        if len(args) == 2:
+            parts = args[1].split(":")
+            if len(parts) == 1:
+                host = parts[0]
+                port = None
+            elif len(parts) == 2:
+                host, port = parts
+            else:
+                sys.exit("Invalid host:port specification.")
+        elif len(args) == 1:
+            host, port = None, None
+        if not host:
+            host = '0.0.0.0'
+        if not port:
+            port = 9999
+        try:
+            port = int(port)
+        except:
+            sys.exit("Invalid host:port specification.")
+        app = Cling(args[0])
+        try:
+            make_server(host, port, app).serve_forever()
+        except KeyboardInterrupt, ki:
+            print "Cio, baby!"
+        except:
+            sys.exit("Problem initializing server.")
+    else:
+        parser.print_help(sys.stderr)
+        sys.exit(1)
 
-    #app = Cling('testdata')
+
+def test():
     magics = StringMagic(title="String Test"), KidMagic(title="Kid Test")
-    app = Shock('testdata', magics=magics)
-    
+    app = Shock('testdata/pub', magics=magics)
     try:
-        from wsgiref.simple_server import make_server
         make_server('localhost', 9999, app).serve_forever()
     except KeyboardInterrupt, ki:
         print "Cio, baby!"
 
+
+if __name__ == '__main__':
+    test()
+
